@@ -9,4 +9,4 @@ sentry.utils.compat
 try:
     import cPickle as pickle
 except ImportError:
-    import pickle
+    import pickle  # NOQA
